from setuptools import setup

setup(name='jeff_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['jeff_distributions'],
      author = 'Jeff Zhong',
      author_email = 'jeffwzhong@gmail.com',
      zip_safe=False)
